<p align="center">
    <!-- <img src="medias/main.gif"/> -->
    <h1 align="center" >T</h1>
    <p align="center">一个简简单单的单词释译器，不翻译哦</p>
        <p align="center">
    <a href="https://app.codacy.com/manual/s045pd/t?utm_source=github.com&utm_medium=referral&utm_content=s045pd/t&utm_campaign=Badge_Grade_Dashboard"><img src="https://api.codacy.com/project/badge/Grade/f00d1d69a99346038d14df4bec303034"/></a>
    <a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.8-green.svg"></a>
    <a target="_blank" href="LICENSE" title="License: MIT"><img src="https://img.shields.io/badge/License-MIT-blue.svg"></a>
</p>

# 安装使用

```sh
git clone https://github.com/s045pd/t.git
cd t
python3 -m venv venv
source venv/bin/activate
pip install -r requirements.txt
python -m t
```

或通过 pip 安装

```bash
pip install cbt
```

# 案例用法

![](https://github.com/s045pd/t/blob/master/data/example.gif)

# 启动选项

```bash
Options:
  -n, --nosay           # 结果发音，默认会
  --online / --offline  # 自动补全数据源，默认使用在线模式
  -l, --sounds [uk|us]  # 口音，默认使用🇬🇧英音
```

# TODO

- 其他语言

# 📝 License

This project is [MIT](https://github.com/s045pd/t/blob/master/LICENSE) licensed.

---

如果您觉得这个脚本对您有用，可别忘了 star 哟 🐶。
